datafusion_cli::helper

Function unescape_input

pub fn unescape_input(input: &str) -> Result<String>
Unescape input string from readline.

The data read from stdio will be escaped, so we need to unescape the input before executing the input