is_stdin_location

Function is_stdin_location 

pub fn is_stdin_location(path: &str) -> bool
Returns true if path refers to the process’s standard input.

Re-exported as crate::object_storage::is_stdin_location so the CLI entry point can detect when it reads its SQL from stdin via -f /dev/stdin and avoid also offering stdin as a LOCATION '/dev/stdin' data source.