Execution functions
Functions
- run and execute SQL statements and commands, against a context with the given print options
- run and execute SQL statements and commands from a file, against a context with the given print options
- run and execute SQL statements and commands against a context with the given print options